==> DateTime-Locale-1.34.tar.gz: DateTime-Locale-1.34/share/tg.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM, y G",
    GyMMMd => "d MMM, y G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd-MM",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-other" => "'\N{U+04b3}\N{U+0430}\N{U+0444}\N{U+0442}\N{U+0430}\N{U+0438}' W, MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "dd-MM",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM-y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM, y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM, y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'\N{U+04b3}\N{U+0430}\N{U+0444}\N{U+0442}\N{U+0430}\N{U+0438}' w, Y",
  },
  code => "tg",
  date_format_full => "EEEE, dd MMMM y",
  date_format_long => "dd MMMM y",
  date_format_medium => "dd MMM y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+0414}\N{U+0448}\N{U+0431}",
    "\N{U+0421}\N{U+0448}\N{U+0431}",
    "\N{U+0427}\N{U+0448}\N{U+0431}",
    "\N{U+041f}\N{U+0448}\N{U+0431}",
    "\N{U+04b6}\N{U+043c}\N{U+044a}",
    "\N{U+0428}\N{U+043d}\N{U+0431}",
    "\N{U+042f}\N{U+0448}\N{U+0431}",
  ],
  day_format_narrow => [
    "\N{U+0414}",
    "\N{U+0421}",
    "\N{U+0427}",
    "\N{U+041f}",
    "\N{U+04b6}",
    "\N{U+0428}",
    "\N{U+042f}",
  ],
  day_format_wide => [
    "\N{U+0414}\N{U+0443}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+0421}\N{U+0435}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+0427}\N{U+043e}\N{U+0440}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+041f}\N{U+0430}\N{U+043d}\N{U+04b7}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+04b6}\N{U+0443}\N{U+043c}\N{U+044a}\N{U+0430}",
    "\N{U+0428}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+042f}\N{U+043a}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0414}\N{U+0448}\N{U+0431}",
    "\N{U+0421}\N{U+0448}\N{U+0431}",
    "\N{U+0427}\N{U+0448}\N{U+0431}",
    "\N{U+041f}\N{U+0448}\N{U+0431}",
    "\N{U+04b6}\N{U+043c}\N{U+044a}",
    "\N{U+0428}\N{U+043d}\N{U+0431}",
    "\N{U+042f}\N{U+0448}\N{U+0431}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0414}",
    "\N{U+0421}",
    "\N{U+0427}",
    "\N{U+041f}",
    "\N{U+04b6}",
    "\N{U+0428}",
    "\N{U+042f}",
  ],
  day_stand_alone_wide => [
    "\N{U+0414}\N{U+0443}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+0421}\N{U+0435}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+0427}\N{U+043e}\N{U+0440}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+041f}\N{U+0430}\N{U+043d}\N{U+04b7}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+04b6}\N{U+0443}\N{U+043c}\N{U+044a}\N{U+0430}",
    "\N{U+0428}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+042f}\N{U+043a}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
  ],
  era_abbreviated => [
    "\N{U+041f}\N{U+0435}\N{U+041c}",
    "\N{U+041f}\N{U+0430}\N{U+041c}",
  ],
  era_narrow => [
    "\N{U+041f}\N{U+0435}\N{U+041c}",
    "\N{U+041f}\N{U+0430}\N{U+041c}",
  ],
  era_wide => [
    "\N{U+041f}\N{U+0435}\N{U+0448} \N{U+0430}\N{U+0437} \N{U+043c}\N{U+0438}\N{U+043b}\N{U+043e}\N{U+0434}",
    "\N{U+041f}\N{U+0430}\N{U+0441} \N{U+0430}\N{U+0437} \N{U+043c}\N{U+0438}\N{U+043b}\N{U+043e}\N{U+0434}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Tajik",
  month_format_abbreviated => [
    "\N{U+042f}\N{U+043d}\N{U+0432}",
    "\N{U+0424}\N{U+0435}\N{U+0432}",
    "\N{U+041c}\N{U+0430}\N{U+0440}",
    "\N{U+0410}\N{U+043f}\N{U+0440}",
    "\N{U+041c}\N{U+0430}\N{U+0439}",
    "\N{U+0418}\N{U+044e}\N{U+043d}",
    "\N{U+0418}\N{U+044e}\N{U+043b}",
    "\N{U+0410}\N{U+0432}\N{U+0433}",
    "\N{U+0421}\N{U+0435}\N{U+043d}",
    "\N{U+041e}\N{U+043a}\N{U+0442}",
    "\N{U+041d}\N{U+043e}\N{U+044f}",
    "\N{U+0414}\N{U+0435}\N{U+043a}",
  ],
  month_format_narrow => [
    "\N{U+042f}",
    "\N{U+0424}",
    "\N{U+041c}",
    "\N{U+0410}",
    "\N{U+041c}",
    "\N{U+0418}",
    "\N{U+0418}",
    "\N{U+0410}",
    "\N{U+0421}",
    "\N{U+041e}",
    "\N{U+041d}",
    "\N{U+0414}",
  ],
  month_format_wide => [
    "\N{U+042f}\N{U+043d}\N{U+0432}\N{U+0430}\N{U+0440}",
    "\N{U+0424}\N{U+0435}\N{U+0432}\N{U+0440}\N{U+0430}\N{U+043b}",
    "\N{U+041c}\N{U+0430}\N{U+0440}\N{U+0442}",
    "\N{U+0410}\N{U+043f}\N{U+0440}\N{U+0435}\N{U+043b}",
    "\N{U+041c}\N{U+0430}\N{U+0439}",
    "\N{U+0418}\N{U+044e}\N{U+043d}",
    "\N{U+0418}\N{U+044e}\N{U+043b}",
    "\N{U+0410}\N{U+0432}\N{U+0433}\N{U+0443}\N{U+0441}\N{U+0442}",
    "\N{U+0421}\N{U+0435}\N{U+043d}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+041e}\N{U+043a}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+041d}\N{U+043e}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+0414}\N{U+0435}\N{U+043a}\N{U+0430}\N{U+0431}\N{U+0440}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+042f}\N{U+043d}\N{U+0432}",
    "\N{U+0424}\N{U+0435}\N{U+0432}",
    "\N{U+041c}\N{U+0430}\N{U+0440}",
    "\N{U+0410}\N{U+043f}\N{U+0440}",
    "\N{U+041c}\N{U+0430}\N{U+0439}",
    "\N{U+0418}\N{U+044e}\N{U+043d}",
    "\N{U+0418}\N{U+044e}\N{U+043b}",
    "\N{U+0410}\N{U+0432}\N{U+0433}",
    "\N{U+0421}\N{U+0435}\N{U+043d}",
    "\N{U+041e}\N{U+043a}\N{U+0442}",
    "\N{U+041d}\N{U+043e}\N{U+044f}",
    "\N{U+0414}\N{U+0435}\N{U+043a}",
  ],
  month_stand_alone_narrow => [
    "\N{U+042f}",
    "\N{U+0424}",
    "\N{U+041c}",
    "\N{U+0410}",
    "\N{U+041c}",
    "\N{U+0418}",
    "\N{U+0418}",
    "\N{U+0410}",
    "\N{U+0421}",
    "\N{U+041e}",
    "\N{U+041d}",
    "\N{U+0414}",
  ],
  month_stand_alone_wide => [
    "\N{U+042f}\N{U+043d}\N{U+0432}\N{U+0430}\N{U+0440}",
    "\N{U+0424}\N{U+0435}\N{U+0432}\N{U+0440}\N{U+0430}\N{U+043b}",
    "\N{U+041c}\N{U+0430}\N{U+0440}\N{U+0442}",
    "\N{U+0410}\N{U+043f}\N{U+0440}\N{U+0435}\N{U+043b}",
    "\N{U+041c}\N{U+0430}\N{U+0439}",
    "\N{U+0418}\N{U+044e}\N{U+043d}",
    "\N{U+0418}\N{U+044e}\N{U+043b}",
    "\N{U+0410}\N{U+0432}\N{U+0433}\N{U+0443}\N{U+0441}\N{U+0442}",
    "\N{U+0421}\N{U+0435}\N{U+043d}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+041e}\N{U+043a}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+041d}\N{U+043e}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+0414}\N{U+0435}\N{U+043a}\N{U+0430}\N{U+0431}\N{U+0440}",
  ],
  name => "Tajik",
  native_language => "\N{U+0442}\N{U+043e}\N{U+04b7}\N{U+0438}\N{U+043a}\N{U+04e3}",
  native_name => "\N{U+0442}\N{U+043e}\N{U+04b7}\N{U+0438}\N{U+043a}\N{U+04e3}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+0427}1",
    "\N{U+0427}2",
    "\N{U+0427}3",
    "\N{U+0427}4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+0427}1",
    "\N{U+0427}2",
    "\N{U+0427}3",
    "\N{U+0427}4",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+0427}1",
    "\N{U+0427}2",
    "\N{U+0427}3",
    "\N{U+0427}4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+0427}1",
    "\N{U+0427}2",
    "\N{U+0427}3",
    "\N{U+0427}4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/tg.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM, y G",
    GyMMMd => "d MMM, y G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd-MM",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-other" => "'\N{U+04b3}\N{U+0430}\N{U+0444}\N{U+0442}\N{U+0430}\N{U+0438}' W, MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "dd-MM",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM-y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM, y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM, y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'\N{U+04b3}\N{U+0430}\N{U+0444}\N{U+0442}\N{U+0430}\N{U+0438}' w, Y",
  },
  code => "tg",
  date_format_full => "EEEE, dd MMMM y",
  date_format_long => "dd MMMM y",
  date_format_medium => "dd MMM y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+0414}\N{U+0448}\N{U+0431}",
    "\N{U+0421}\N{U+0448}\N{U+0431}",
    "\N{U+0427}\N{U+0448}\N{U+0431}",
    "\N{U+041f}\N{U+0448}\N{U+0431}",
    "\N{U+04b6}\N{U+043c}\N{U+044a}",
    "\N{U+0428}\N{U+043d}\N{U+0431}",
    "\N{U+042f}\N{U+0448}\N{U+0431}",
  ],
  day_format_narrow => [
    "\N{U+0414}",
    "\N{U+0421}",
    "\N{U+0427}",
    "\N{U+041f}",
    "\N{U+04b6}",
    "\N{U+0428}",
    "\N{U+042f}",
  ],
  day_format_wide => [
    "\N{U+0414}\N{U+0443}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+0421}\N{U+0435}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+0427}\N{U+043e}\N{U+0440}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+041f}\N{U+0430}\N{U+043d}\N{U+04b7}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+04b6}\N{U+0443}\N{U+043c}\N{U+044a}\N{U+0430}",
    "\N{U+0428}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+042f}\N{U+043a}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0414}\N{U+0448}\N{U+0431}",
    "\N{U+0421}\N{U+0448}\N{U+0431}",
    "\N{U+0427}\N{U+0448}\N{U+0431}",
    "\N{U+041f}\N{U+0448}\N{U+0431}",
    "\N{U+04b6}\N{U+043c}\N{U+044a}",
    "\N{U+0428}\N{U+043d}\N{U+0431}",
    "\N{U+042f}\N{U+0448}\N{U+0431}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0414}",
    "\N{U+0421}",
    "\N{U+0427}",
    "\N{U+041f}",
    "\N{U+04b6}",
    "\N{U+0428}",
    "\N{U+042f}",
  ],
  day_stand_alone_wide => [
    "\N{U+0414}\N{U+0443}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+0421}\N{U+0435}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+0427}\N{U+043e}\N{U+0440}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+041f}\N{U+0430}\N{U+043d}\N{U+04b7}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+04b6}\N{U+0443}\N{U+043c}\N{U+044a}\N{U+0430}",
    "\N{U+0428}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
    "\N{U+042f}\N{U+043a}\N{U+0448}\N{U+0430}\N{U+043d}\N{U+0431}\N{U+0435}",
  ],
  era_abbreviated => [
    "\N{U+041f}\N{U+0435}\N{U+041c}",
    "\N{U+041f}\N{U+0430}\N{U+041c}",
  ],
  era_narrow => [
    "\N{U+041f}\N{U+0435}\N{U+041c}",
    "\N{U+041f}\N{U+0430}\N{U+041c}",
  ],
  era_wide => [
    "\N{U+041f}\N{U+0435}\N{U+0448} \N{U+0430}\N{U+0437} \N{U+043c}\N{U+0438}\N{U+043b}\N{U+043e}\N{U+0434}",
    "\N{U+041f}\N{U+0430}\N{U+0441} \N{U+0430}\N{U+0437} \N{U+043c}\N{U+0438}\N{U+043b}\N{U+043e}\N{U+0434}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Tajik",
  month_format_abbreviated => [
    "\N{U+042f}\N{U+043d}\N{U+0432}",
    "\N{U+0424}\N{U+0435}\N{U+0432}",
    "\N{U+041c}\N{U+0430}\N{U+0440}",
    "\N{U+0410}\N{U+043f}\N{U+0440}",
    "\N{U+041c}\N{U+0430}\N{U+0439}",
    "\N{U+0418}\N{U+044e}\N{U+043d}",
    "\N{U+0418}\N{U+044e}\N{U+043b}",
    "\N{U+0410}\N{U+0432}\N{U+0433}",
    "\N{U+0421}\N{U+0435}\N{U+043d}",
    "\N{U+041e}\N{U+043a}\N{U+0442}",
    "\N{U+041d}\N{U+043e}\N{U+044f}",
    "\N{U+0414}\N{U+0435}\N{U+043a}",
  ],
  month_format_narrow => [
    "\N{U+042f}",
    "\N{U+0424}",
    "\N{U+041c}",
    "\N{U+0410}",
    "\N{U+041c}",
    "\N{U+0418}",
    "\N{U+0418}",
    "\N{U+0410}",
    "\N{U+0421}",
    "\N{U+041e}",
    "\N{U+041d}",
    "\N{U+0414}",
  ],
  month_format_wide => [
    "\N{U+042f}\N{U+043d}\N{U+0432}\N{U+0430}\N{U+0440}",
    "\N{U+0424}\N{U+0435}\N{U+0432}\N{U+0440}\N{U+0430}\N{U+043b}",
    "\N{U+041c}\N{U+0430}\N{U+0440}\N{U+0442}",
    "\N{U+0410}\N{U+043f}\N{U+0440}\N{U+0435}\N{U+043b}",
    "\N{U+041c}\N{U+0430}\N{U+0439}",
    "\N{U+0418}\N{U+044e}\N{U+043d}",
    "\N{U+0418}\N{U+044e}\N{U+043b}",
    "\N{U+0410}\N{U+0432}\N{U+0433}\N{U+0443}\N{U+0441}\N{U+0442}",
    "\N{U+0421}\N{U+0435}\N{U+043d}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+041e}\N{U+043a}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+041d}\N{U+043e}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+0414}\N{U+0435}\N{U+043a}\N{U+0430}\N{U+0431}\N{U+0440}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+042f}\N{U+043d}\N{U+0432}",
    "\N{U+0424}\N{U+0435}\N{U+0432}",
    "\N{U+041c}\N{U+0430}\N{U+0440}",
    "\N{U+0410}\N{U+043f}\N{U+0440}",
    "\N{U+041c}\N{U+0430}\N{U+0439}",
    "\N{U+0418}\N{U+044e}\N{U+043d}",
    "\N{U+0418}\N{U+044e}\N{U+043b}",
    "\N{U+0410}\N{U+0432}\N{U+0433}",
    "\N{U+0421}\N{U+0435}\N{U+043d}",
    "\N{U+041e}\N{U+043a}\N{U+0442}",
    "\N{U+041d}\N{U+043e}\N{U+044f}",
    "\N{U+0414}\N{U+0435}\N{U+043a}",
  ],
  month_stand_alone_narrow => [
    "\N{U+042f}",
    "\N{U+0424}",
    "\N{U+041c}",
    "\N{U+0410}",
    "\N{U+041c}",
    "\N{U+0418}",
    "\N{U+0418}",
    "\N{U+0410}",
    "\N{U+0421}",
    "\N{U+041e}",
    "\N{U+041d}",
    "\N{U+0414}",
  ],
  month_stand_alone_wide => [
    "\N{U+042f}\N{U+043d}\N{U+0432}\N{U+0430}\N{U+0440}",
    "\N{U+0424}\N{U+0435}\N{U+0432}\N{U+0440}\N{U+0430}\N{U+043b}",
    "\N{U+041c}\N{U+0430}\N{U+0440}\N{U+0442}",
    "\N{U+0410}\N{U+043f}\N{U+0440}\N{U+0435}\N{U+043b}",
    "\N{U+041c}\N{U+0430}\N{U+0439}",
    "\N{U+0418}\N{U+044e}\N{U+043d}",
    "\N{U+0418}\N{U+044e}\N{U+043b}",
    "\N{U+0410}\N{U+0432}\N{U+0433}\N{U+0443}\N{U+0441}\N{U+0442}",
    "\N{U+0421}\N{U+0435}\N{U+043d}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+041e}\N{U+043a}\N{U+0442}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+041d}\N{U+043e}\N{U+044f}\N{U+0431}\N{U+0440}",
    "\N{U+0414}\N{U+0435}\N{U+043a}\N{U+0430}\N{U+0431}\N{U+0440}",
  ],
  name => "Tajik",
  native_language => "\N{U+0442}\N{U+043e}\N{U+04b7}\N{U+0438}\N{U+043a}\N{U+04e3}",
  native_name => "\N{U+0442}\N{U+043e}\N{U+04b7}\N{U+0438}\N{U+043a}\N{U+04e3}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+0427}1",
    "\N{U+0427}2",
    "\N{U+0427}3",
    "\N{U+0427}4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+0427}1",
    "\N{U+0427}2",
    "\N{U+0427}3",
    "\N{U+0427}4",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+0427}1",
    "\N{U+0427}2",
    "\N{U+0427}3",
    "\N{U+0427}4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+0427}1",
    "\N{U+0427}2",
    "\N{U+0427}3",
    "\N{U+0427}4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => "44.1",
}
